# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/campaign_extension_setting.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import extension_setting_device_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_extension__setting__device__pb2
from google.ads.google_ads.v2.proto.enums import extension_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_extension__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/campaign_extension_setting.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\035CampaignExtensionSettingProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\nHgoogle/ads/googleads_v2/proto/resources/campaign_extension_setting.proto\x12!google.ads.googleads.v2.resources\x1a\x42google/ads/googleads_v2/proto/enums/extension_setting_device.proto\x1a\x38google/ads/googleads_v2/proto/enums/extension_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xd7\x02\n\x18\x43\x61mpaignExtensionSetting\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12V\n\x0e\x65xtension_type\x18\x02 \x01(\x0e\x32>.google.ads.googleads.v2.enums.ExtensionTypeEnum.ExtensionType\x12.\n\x08\x63\x61mpaign\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x65xtension_feed_items\x18\x04 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12`\n\x06\x64\x65vice\x18\x05 \x01(\x0e\x32P.google.ads.googleads.v2.enums.ExtensionSettingDeviceEnum.ExtensionSettingDeviceB\x8a\x02\n%com.google.ads.googleads.v2.resourcesB\x1d\x43\x61mpaignExtensionSettingProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_extension__setting__device__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_extension__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGNEXTENSIONSETTING = _descriptor.Descriptor(
  name='CampaignExtensionSetting',
  full_name='google.ads.googleads.v2.resources.CampaignExtensionSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.CampaignExtensionSetting.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension_type', full_name='google.ads.googleads.v2.resources.CampaignExtensionSetting.extension_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v2.resources.CampaignExtensionSetting.campaign', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension_feed_items', full_name='google.ads.googleads.v2.resources.CampaignExtensionSetting.extension_feed_items', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='google.ads.googleads.v2.resources.CampaignExtensionSetting.device', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=643,
)

_CAMPAIGNEXTENSIONSETTING.fields_by_name['extension_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_extension__type__pb2._EXTENSIONTYPEENUM_EXTENSIONTYPE
_CAMPAIGNEXTENSIONSETTING.fields_by_name['campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXTENSIONSETTING.fields_by_name['extension_feed_items'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXTENSIONSETTING.fields_by_name['device'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_extension__setting__device__pb2._EXTENSIONSETTINGDEVICEENUM_EXTENSIONSETTINGDEVICE
DESCRIPTOR.message_types_by_name['CampaignExtensionSetting'] = _CAMPAIGNEXTENSIONSETTING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignExtensionSetting = _reflection.GeneratedProtocolMessageType('CampaignExtensionSetting', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNEXTENSIONSETTING,
  __module__ = 'google.ads.googleads_v2.proto.resources.campaign_extension_setting_pb2'
  ,
  __doc__ = """A campaign extension setting.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign extension setting.
          CampaignExtensionSetting resource names have the form:  ``cust
          omers/{customer_id}/campaignExtensionSettings/{campaign_id}~{e
          xtension_type}``
      extension_type:
          The extension type of the customer extension setting.
      campaign:
          The resource name of the campaign. The linked extension feed
          items will serve under this campaign. Campaign resource names
          have the form:
          ``customers/{customer_id}/campaigns/{campaign_id}``
      extension_feed_items:
          The resource names of the extension feed items to serve under
          the campaign. ExtensionFeedItem resource names have the form:
          ``customers/{customer_id}/extensionFeedItems/{feed_item_id}``
      device:
          The device for which the extensions will serve. Optional.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.CampaignExtensionSetting)
  ))
_sym_db.RegisterMessage(CampaignExtensionSetting)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/promotion_placeholder_field.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/promotion_placeholder_field.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\036PromotionPlaceholderFieldProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\nEgoogle/ads/googleads_v1/proto/enums/promotion_placeholder_field.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xee\x02\n\x1dPromotionPlaceholderFieldEnum\"\xcc\x02\n\x19PromotionPlaceholderField\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x14\n\x10PROMOTION_TARGET\x10\x02\x12\x15\n\x11\x44ISCOUNT_MODIFIER\x10\x03\x12\x0f\n\x0bPERCENT_OFF\x10\x04\x12\x14\n\x10MONEY_AMOUNT_OFF\x10\x05\x12\x12\n\x0ePROMOTION_CODE\x10\x06\x12\x16\n\x12ORDERS_OVER_AMOUNT\x10\x07\x12\x13\n\x0fPROMOTION_START\x10\x08\x12\x11\n\rPROMOTION_END\x10\t\x12\x0c\n\x08OCCASION\x10\n\x12\x0e\n\nFINAL_URLS\x10\x0b\x12\x15\n\x11\x46INAL_MOBILE_URLS\x10\x0c\x12\x10\n\x0cTRACKING_URL\x10\r\x12\x0c\n\x08LANGUAGE\x10\x0e\x12\x14\n\x10\x46INAL_URL_SUFFIX\x10\x0f\x42\xf3\x01\n!com.google.ads.googleads.v1.enumsB\x1ePromotionPlaceholderFieldProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_PROMOTIONPLACEHOLDERFIELDENUM_PROMOTIONPLACEHOLDERFIELD = _descriptor.EnumDescriptor(
  name='PromotionPlaceholderField',
  full_name='google.ads.googleads.v1.enums.PromotionPlaceholderFieldEnum.PromotionPlaceholderField',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTION_TARGET', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISCOUNT_MODIFIER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERCENT_OFF', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONEY_AMOUNT_OFF', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTION_CODE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDERS_OVER_AMOUNT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTION_START', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTION_END', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OCCASION', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_URLS', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_MOBILE_URLS', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACKING_URL', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANGUAGE', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_URL_SUFFIX', index=15, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=169,
  serialized_end=501,
)
_sym_db.RegisterEnumDescriptor(_PROMOTIONPLACEHOLDERFIELDENUM_PROMOTIONPLACEHOLDERFIELD)


_PROMOTIONPLACEHOLDERFIELDENUM = _descriptor.Descriptor(
  name='PromotionPlaceholderFieldEnum',
  full_name='google.ads.googleads.v1.enums.PromotionPlaceholderFieldEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROMOTIONPLACEHOLDERFIELDENUM_PROMOTIONPLACEHOLDERFIELD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=501,
)

_PROMOTIONPLACEHOLDERFIELDENUM_PROMOTIONPLACEHOLDERFIELD.containing_type = _PROMOTIONPLACEHOLDERFIELDENUM
DESCRIPTOR.message_types_by_name['PromotionPlaceholderFieldEnum'] = _PROMOTIONPLACEHOLDERFIELDENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PromotionPlaceholderFieldEnum = _reflection.GeneratedProtocolMessageType('PromotionPlaceholderFieldEnum', (_message.Message,), dict(
  DESCRIPTOR = _PROMOTIONPLACEHOLDERFIELDENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.promotion_placeholder_field_pb2'
  ,
  __doc__ = """Values for Promotion placeholder fields.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.PromotionPlaceholderFieldEnum)
  ))
_sym_db.RegisterMessage(PromotionPlaceholderFieldEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/account_budget_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.resources import account_budget_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/account_budget_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\031AccountBudgetServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v2/proto/services/account_budget_service.proto\x12 google.ads.googleads.v2.services\x1a<google/ads/googleads_v2/proto/resources/account_budget.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\"0\n\x17GetAccountBudgetRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xef\x01\n\x14\x41\x63\x63ountBudgetService\x12\xb9\x01\n\x10GetAccountBudget\x12\x39.google.ads.googleads.v2.services.GetAccountBudgetRequest\x1a\x30.google.ads.googleads.v2.resources.AccountBudget\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v2/{resource_name=customers/*/accountBudgets/*}\x1a\x1b\xca\x41\x18googleads.googleapis.comB\x80\x02\n$com.google.ads.googleads.v2.servicesB\x19\x41\x63\x63ountBudgetServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_GETACCOUNTBUDGETREQUEST = _descriptor.Descriptor(
  name='GetAccountBudgetRequest',
  full_name='google.ads.googleads.v2.services.GetAccountBudgetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.GetAccountBudgetRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=270,
)

DESCRIPTOR.message_types_by_name['GetAccountBudgetRequest'] = _GETACCOUNTBUDGETREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAccountBudgetRequest = _reflection.GeneratedProtocolMessageType('GetAccountBudgetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTBUDGETREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.account_budget_service_pb2'
  ,
  __doc__ = """Request message for
  [AccountBudgetService.GetAccountBudget][google.ads.googleads.v2.services.AccountBudgetService.GetAccountBudget].
  
  
  Attributes:
      resource_name:
          The resource name of the account-level budget to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GetAccountBudgetRequest)
  ))
_sym_db.RegisterMessage(GetAccountBudgetRequest)


DESCRIPTOR._options = None

_ACCOUNTBUDGETSERVICE = _descriptor.ServiceDescriptor(
  name='AccountBudgetService',
  full_name='google.ads.googleads.v2.services.AccountBudgetService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=273,
  serialized_end=512,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAccountBudget',
    full_name='google.ads.googleads.v2.services.AccountBudgetService.GetAccountBudget',
    index=0,
    containing_service=None,
    input_type=_GETACCOUNTBUDGETREQUEST,
    output_type=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__pb2._ACCOUNTBUDGET,
    serialized_options=_b('\202\323\344\223\0022\0220/v2/{resource_name=customers/*/accountBudgets/*}'),
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCOUNTBUDGETSERVICE)

DESCRIPTOR.services_by_name['AccountBudgetService'] = _ACCOUNTBUDGETSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""A client and common configurations for the Google Ads API."""

import grpc
from importlib import import_module
import logging.config

from google.ads.google_ads import config, oauth2, util
from google.ads.google_ads.interceptors import MetadataInterceptor, \
    ExceptionInterceptor, LoggingInterceptor


_logger = logging.getLogger(__name__)

_SERVICE_CLIENT_TEMPLATE = '{}Client'
_SERVICE_GRPC_TRANSPORT_TEMPLATE = '{}GrpcTransport'

_VALID_API_VERSIONS = ['v2', 'v1']
_DEFAULT_VERSION = _VALID_API_VERSIONS[0]

_GRPC_CHANNEL_OPTIONS = [
    ('grpc.max_metadata_size', 16 * 1024 * 1024),
    ('grpc.max_receive_message_length', 64 * 1024 * 1024)]


unary_stream_single_threading_option = util.get_nested_attr(
    grpc, 'experimental.ChannelOptions.SingleThreadedUnaryStream', None)

if unary_stream_single_threading_option:
    _GRPC_CHANNEL_OPTIONS.append(
        (unary_stream_single_threading_option, 1))


class GoogleAdsClient(object):
    """Google Ads client used to configure settings and fetch services."""

    @classmethod
    def _get_client_kwargs(cls, config_data):
        """Converts configuration dict into kwargs required by the client.

        Args:
            config_data: a dict containing client configuration.

        Returns:
            A dict containing kwargs that will be provided to the
            GoogleAdsClient initializer.

        Raises:
            ValueError: If the configuration lacks a required field.
        """
        return {'credentials': oauth2.get_credentials(config_data),
                'developer_token': config_data.get('developer_token'),
                'endpoint': config_data.get('endpoint'),
                'login_customer_id': config_data.get('login_customer_id'),
                'logging_config': config_data.get('logging')}

    @classmethod
    def _get_api_services_by_version(cls, version):
        """Returns a module with all services and types for a given API version.

        Args:
            version: a str indicating the API version.

        Returns:
            A module containing all services and types for the a API version.
        """
        try:
            version_module = import_module(f'google.ads.google_ads.{version}')
        except ImportError:
            raise ValueError('Specified Google Ads API version "{}" does not '
                             'exist. Valid API versions are: "{}"'.format(
                                 version, '", "'.join(_VALID_API_VERSIONS)))
        return version_module

    @classmethod
    def load_from_env(cls):
        """Creates a GoogleAdsClient with data stored in the env variables.

        Returns:
            A GoogleAdsClient initialized with the values specified in the
            env variables.

        Raises:
            ValueError: If the configuration lacks a required field.
        """
        config_data = config.load_from_env()
        kwargs = cls._get_client_kwargs(config_data)
        return cls(**kwargs)

    @classmethod
    def load_from_string(cls, yaml_str):
        """Creates a GoogleAdsClient with data stored in the YAML string.

        Args:
            yaml_str: a str containing YAML configuration data used to
                initialize a GoogleAdsClient.

        Returns:
            A GoogleAdsClient initialized with the values specified in the
            string.

        Raises:
            ValueError: If the configuration lacks a required field.
        """
        config_data = config.parse_yaml_document_to_dict(yaml_str)
        kwargs = cls._get_client_kwargs(config_data)
        return cls(**kwargs)

    @classmethod  
    def load_from_dict(cls, config_dict):
        """Creates a GoogleAdsClient with data stored in the config_dict.

        Args:
            config_dict: a dict consisting of configuration data used to
                initialize a GoogleAdsClient.

        Returns:
            A GoogleAdsClient initialized with the values specified in the
                dict.

        Raises:
            ValueError: If the configuration lacks a required field.
        """
        config_data = config.load_from_dict(config_dict)
        kwargs = cls._get_client_kwargs(config_data)
        return cls(**kwargs)

    @classmethod
    def load_from_storage(cls, path=None):
        """Creates a GoogleAdsClient with data stored in the specified file.

        Args:
            path: a str indicating the path to a YAML file containing
                configuration data used to initialize a GoogleAdsClient.

        Returns:
            A GoogleAdsClient initialized with the values in the specified file.

        Raises:
            FileNotFoundError: If the specified configuration file doesn't
                exist.
            IOError: If the configuration file can't be loaded.
            ValueError: If the configuration file lacks a required field.
        """
        config_data = config.load_from_yaml_file(path)
        kwargs = cls._get_client_kwargs(config_data)
        return cls(**kwargs)

    @classmethod
    def get_type(cls, name, version=_DEFAULT_VERSION):
        """Returns the specified common, enum, error, or resource type.

        Args:
            name: a str indicating the name of the type that is being retrieved;
                e.g. you may specify "CampaignOperation" to retrieve a
                CampaignOperation instance.
            version: a str indicating the the Google Ads API version to be used.

        Returns:
            A Message instance representing the desired type.

        Raises:
            AttributeError: If the type for the specified name doesn't exist
                in the given version.
        """
        if name.lower().endswith('pb2'):
            raise ValueError(f'Specified type "{name}" must be a class,'
                             f' not a module')
        
        try:
            type_classes = cls._get_api_services_by_version(version).types
            message_class = getattr(type_classes, name)
        except AttributeError:
            raise ValueError(f'Specified type "{name}" does not exist in Google Ads '
                             f'API {version}')
        return message_class()

    def __init__(self, credentials, developer_token, endpoint=None,
                 login_customer_id=None, logging_config=None):
        """Initializer for the GoogleAdsClient.

        Args:
            credentials: a google.oauth2.credentials.Credentials instance.
            developer_token: a str developer token.
            endpoint: a str specifying an optional alternative API endpoint.
            login_customer_id: a str specifying a login customer ID.
            logging_config: a dict specifying logging config options.
        """
        if logging_config:
            logging.config.dictConfig(logging_config)

        self.credentials = credentials
        self.developer_token = developer_token
        self.endpoint = endpoint
        self.login_customer_id = login_customer_id

    def get_service(self, name, version=_DEFAULT_VERSION, interceptors=[]):
        """Returns a service client instance for the specified service_name.

        Args:
            name: a str indicating the name of the service for which a
                service client is being retrieved; e.g. you may specify
                "CampaignService" to retrieve a CampaignServiceClient instance.
            version: a str indicating the version of the Google Ads API to be
                used.
            interceptors: an optional list of interceptors to include in
                requests. NOTE: this parameter is not intended for non-Google
                use and is not officially supported.

        Returns:
            A service client instance associated with the given service_name.

        Raises:
            AttributeError: If the specified name doesn't exist.
        """
        api_module = self._get_api_services_by_version(version)

        try:
            service_client = getattr(api_module,
                                     _SERVICE_CLIENT_TEMPLATE.format(name))
        except AttributeError:
            raise ValueError('Specified service {}" does not exist in Google '
                             'Ads API {}.'.format(name, version))

        try:
            service_transport_class = getattr(
                api_module, _SERVICE_GRPC_TRANSPORT_TEMPLATE.format(name))
        except AttributeError:
            raise ValueError('Grpc transport does not exist for the specified '
                             'service "{}".'.format(name))

        endpoint = (self.endpoint if self.endpoint
                    else service_client.SERVICE_ADDRESS)

        channel = service_transport_class.create_channel(
            address=endpoint,
            credentials=self.credentials,
            options=_GRPC_CHANNEL_OPTIONS)

        interceptors = interceptors + [
            MetadataInterceptor(self.developer_token, self.login_customer_id),
            LoggingInterceptor(_logger, endpoint),
            ExceptionInterceptor(version)]

        channel = grpc.intercept_channel(
            channel,
            *interceptors)

        service_transport = service_transport_class(channel=channel)

        return service_client(transport=service_transport)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/campaign_experiment.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import campaign_experiment_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__status__pb2
from google.ads.google_ads.v1.proto.enums import campaign_experiment_traffic_split_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__traffic__split__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/campaign_experiment.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\027CampaignExperimentProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nAgoogle/ads/googleads_v1/proto/resources/campaign_experiment.proto\x12!google.ads.googleads.v1.resources\x1a\x44google/ads/googleads_v1/proto/enums/campaign_experiment_status.proto\x1aPgoogle/ads/googleads_v1/proto/enums/campaign_experiment_traffic_split_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xed\x05\n\x12\x43\x61mpaignExperiment\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0e\x63\x61mpaign_draft\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x15traffic_split_percent\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x84\x01\n\x12traffic_split_type\x18\x07 \x01(\x0e\x32h.google.ads.googleads.v1.enums.CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitType\x12\x39\n\x13\x65xperiment_campaign\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x64\n\x06status\x18\t \x01(\x0e\x32T.google.ads.googleads.v1.enums.CampaignExperimentStatusEnum.CampaignExperimentStatus\x12<\n\x16long_running_operation\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nstart_date\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65nd_date\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x84\x02\n%com.google.ads.googleads.v1.resourcesB\x17\x43\x61mpaignExperimentProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__traffic__split__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGNEXPERIMENT = _descriptor.Descriptor(
  name='CampaignExperiment',
  full_name='google.ads.googleads.v1.resources.CampaignExperiment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.CampaignExperiment.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.CampaignExperiment.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_draft', full_name='google.ads.googleads.v1.resources.CampaignExperiment.campaign_draft', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.CampaignExperiment.name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v1.resources.CampaignExperiment.description', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traffic_split_percent', full_name='google.ads.googleads.v1.resources.CampaignExperiment.traffic_split_percent', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traffic_split_type', full_name='google.ads.googleads.v1.resources.CampaignExperiment.traffic_split_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_campaign', full_name='google.ads.googleads.v1.resources.CampaignExperiment.experiment_campaign', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.CampaignExperiment.status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_running_operation', full_name='google.ads.googleads.v1.resources.CampaignExperiment.long_running_operation', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='google.ads.googleads.v1.resources.CampaignExperiment.start_date', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='google.ads.googleads.v1.resources.CampaignExperiment.end_date', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=1068,
)

_CAMPAIGNEXPERIMENT.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNEXPERIMENT.fields_by_name['campaign_draft'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['traffic_split_percent'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNEXPERIMENT.fields_by_name['traffic_split_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__traffic__split__type__pb2._CAMPAIGNEXPERIMENTTRAFFICSPLITTYPEENUM_CAMPAIGNEXPERIMENTTRAFFICSPLITTYPE
_CAMPAIGNEXPERIMENT.fields_by_name['experiment_campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__status__pb2._CAMPAIGNEXPERIMENTSTATUSENUM_CAMPAIGNEXPERIMENTSTATUS
_CAMPAIGNEXPERIMENT.fields_by_name['long_running_operation'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['start_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['end_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['CampaignExperiment'] = _CAMPAIGNEXPERIMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignExperiment = _reflection.GeneratedProtocolMessageType('CampaignExperiment', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNEXPERIMENT,
  __module__ = 'google.ads.googleads_v1.proto.resources.campaign_experiment_pb2'
  ,
  __doc__ = """An A/B experiment that compares the performance of the base campaign
  (the control) and a variation of that campaign (the experiment).
  
  
  Attributes:
      resource_name:
          The resource name of the campaign experiment. Campaign
          experiment resource names have the form:  ``customers/{custome
          r_id}/campaignExperiments/{campaign_experiment_id}``
      id:
          The ID of the campaign experiment.  This field is read-only.
      campaign_draft:
          The campaign draft with staged changes to the base campaign.
      name:
          The name of the campaign experiment.  This field is required
          when creating new campaign experiments and must not conflict
          with the name of another non-removed campaign experiment or
          campaign.  It must not contain any null (code point 0x0), NL
          line feed (code point 0xA) or carriage return (code point 0xD)
          characters.
      description:
          The description of the experiment.
      traffic_split_percent:
          Share of traffic directed to experiment as a percent (must be
          between 1 and 99 inclusive. Base campaign receives the
          remainder of the traffic (100 - traffic\_split\_percent).
          Required for create.
      traffic_split_type:
          Determines the behavior of the traffic split.
      experiment_campaign:
          The experiment campaign, as opposed to the base campaign.
      status:
          The status of the campaign experiment. This field is read-
          only.
      long_running_operation:
          The resource name of the long-running operation that can be
          used to poll for completion of experiment create or promote.
          The most recent long running operation is returned.
      start_date:
          Date when the campaign experiment starts. By default, the
          experiment starts now or on the campaign's start date,
          whichever is later. If this field is set, then the experiment
          starts at the beginning of the specified date in the
          customer's time zone. Cannot be changed once the experiment
          starts.  Format: YYYY-MM-DD Example: 2019-03-14
      end_date:
          Date when the campaign experiment ends. By default, the
          experiment ends on the campaign's end date. If this field is
          set, then the experiment ends at the end of the specified date
          in the customer's time zone.  Format: YYYY-MM-DD Example:
          2019-04-18
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.CampaignExperiment)
  ))
_sym_db.RegisterMessage(CampaignExperiment)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/bidding_strategy.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import bidding_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2
from google.ads.google_ads.v2.proto.enums import bidding_strategy_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__strategy__status__pb2
from google.ads.google_ads.v2.proto.enums import bidding_strategy_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__strategy__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/bidding_strategy.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\024BiddingStrategyProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n>google/ads/googleads_v2/proto/resources/bidding_strategy.proto\x12!google.ads.googleads.v2.resources\x1a\x32google/ads/googleads_v2/proto/common/bidding.proto\x1a\x41google/ads/googleads_v2/proto/enums/bidding_strategy_status.proto\x1a?google/ads/googleads_v2/proto/enums/bidding_strategy_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xc1\x07\n\x0f\x42iddingStrategy\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12^\n\x06status\x18\x0f \x01(\x0e\x32N.google.ads.googleads.v2.enums.BiddingStrategyStatusEnum.BiddingStrategyStatus\x12X\n\x04type\x18\x05 \x01(\x0e\x32J.google.ads.googleads.v2.enums.BiddingStrategyTypeEnum.BiddingStrategyType\x12\x33\n\x0e\x63\x61mpaign_count\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1anon_removed_campaign_count\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x0c\x65nhanced_cpc\x18\x07 \x01(\x0b\x32+.google.ads.googleads.v2.common.EnhancedCpcH\x00\x12L\n\x11page_one_promoted\x18\x08 \x01(\x0b\x32/.google.ads.googleads.v2.common.PageOnePromotedH\x00\x12?\n\ntarget_cpa\x18\t \x01(\x0b\x32).google.ads.googleads.v2.common.TargetCpaH\x00\x12X\n\x17target_impression_share\x18\x30 \x01(\x0b\x32\x35.google.ads.googleads.v2.common.TargetImpressionShareH\x00\x12R\n\x14target_outrank_share\x18\n \x01(\x0b\x32\x32.google.ads.googleads.v2.common.TargetOutrankShareH\x00\x12\x41\n\x0btarget_roas\x18\x0b \x01(\x0b\x32*.google.ads.googleads.v2.common.TargetRoasH\x00\x12\x43\n\x0ctarget_spend\x18\x0c \x01(\x0b\x32+.google.ads.googleads.v2.common.TargetSpendH\x00\x42\x08\n\x06schemeB\x81\x02\n%com.google.ads.googleads.v2.resourcesB\x14\x42iddingStrategyProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__strategy__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__strategy__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_BIDDINGSTRATEGY = _descriptor.Descriptor(
  name='BiddingStrategy',
  full_name='google.ads.googleads.v2.resources.BiddingStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.BiddingStrategy.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.BiddingStrategy.id', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.BiddingStrategy.name', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.BiddingStrategy.status', index=3,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.resources.BiddingStrategy.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_count', full_name='google.ads.googleads.v2.resources.BiddingStrategy.campaign_count', index=5,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_removed_campaign_count', full_name='google.ads.googleads.v2.resources.BiddingStrategy.non_removed_campaign_count', index=6,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enhanced_cpc', full_name='google.ads.googleads.v2.resources.BiddingStrategy.enhanced_cpc', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_one_promoted', full_name='google.ads.googleads.v2.resources.BiddingStrategy.page_one_promoted', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_cpa', full_name='google.ads.googleads.v2.resources.BiddingStrategy.target_cpa', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_impression_share', full_name='google.ads.googleads.v2.resources.BiddingStrategy.target_impression_share', index=10,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_outrank_share', full_name='google.ads.googleads.v2.resources.BiddingStrategy.target_outrank_share', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_roas', full_name='google.ads.googleads.v2.resources.BiddingStrategy.target_roas', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_spend', full_name='google.ads.googleads.v2.resources.BiddingStrategy.target_spend', index=13,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='scheme', full_name='google.ads.googleads.v2.resources.BiddingStrategy.scheme',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=348,
  serialized_end=1309,
)

_BIDDINGSTRATEGY.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BIDDINGSTRATEGY.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BIDDINGSTRATEGY.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__strategy__status__pb2._BIDDINGSTRATEGYSTATUSENUM_BIDDINGSTRATEGYSTATUS
_BIDDINGSTRATEGY.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_bidding__strategy__type__pb2._BIDDINGSTRATEGYTYPEENUM_BIDDINGSTRATEGYTYPE
_BIDDINGSTRATEGY.fields_by_name['campaign_count'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BIDDINGSTRATEGY.fields_by_name['non_removed_campaign_count'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BIDDINGSTRATEGY.fields_by_name['enhanced_cpc'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._ENHANCEDCPC
_BIDDINGSTRATEGY.fields_by_name['page_one_promoted'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._PAGEONEPROMOTED
_BIDDINGSTRATEGY.fields_by_name['target_cpa'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._TARGETCPA
_BIDDINGSTRATEGY.fields_by_name['target_impression_share'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._TARGETIMPRESSIONSHARE
_BIDDINGSTRATEGY.fields_by_name['target_outrank_share'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._TARGETOUTRANKSHARE
_BIDDINGSTRATEGY.fields_by_name['target_roas'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._TARGETROAS
_BIDDINGSTRATEGY.fields_by_name['target_spend'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_bidding__pb2._TARGETSPEND
_BIDDINGSTRATEGY.oneofs_by_name['scheme'].fields.append(
  _BIDDINGSTRATEGY.fields_by_name['enhanced_cpc'])
_BIDDINGSTRATEGY.fields_by_name['enhanced_cpc'].containing_oneof = _BIDDINGSTRATEGY.oneofs_by_name['scheme']
_BIDDINGSTRATEGY.oneofs_by_name['scheme'].fields.append(
  _BIDDINGSTRATEGY.fields_by_name['page_one_promoted'])
_BIDDINGSTRATEGY.fields_by_name['page_one_promoted'].containing_oneof = _BIDDINGSTRATEGY.oneofs_by_name['scheme']
_BIDDINGSTRATEGY.oneofs_by_name['scheme'].fields.append(
  _BIDDINGSTRATEGY.fields_by_name['target_cpa'])
_BIDDINGSTRATEGY.fields_by_name['target_cpa'].containing_oneof = _BIDDINGSTRATEGY.oneofs_by_name['scheme']
_BIDDINGSTRATEGY.oneofs_by_name['scheme'].fields.append(
  _BIDDINGSTRATEGY.fields_by_name['target_impression_share'])
_BIDDINGSTRATEGY.fields_by_name['target_impression_share'].containing_oneof = _BIDDINGSTRATEGY.oneofs_by_name['scheme']
_BIDDINGSTRATEGY.oneofs_by_name['scheme'].fields.append(
  _BIDDINGSTRATEGY.fields_by_name['target_outrank_share'])
_BIDDINGSTRATEGY.fields_by_name['target_outrank_share'].containing_oneof = _BIDDINGSTRATEGY.oneofs_by_name['scheme']
_BIDDINGSTRATEGY.oneofs_by_name['scheme'].fields.append(
  _BIDDINGSTRATEGY.fields_by_name['target_roas'])
_BIDDINGSTRATEGY.fields_by_name['target_roas'].containing_oneof = _BIDDINGSTRATEGY.oneofs_by_name['scheme']
_BIDDINGSTRATEGY.oneofs_by_name['scheme'].fields.append(
  _BIDDINGSTRATEGY.fields_by_name['target_spend'])
_BIDDINGSTRATEGY.fields_by_name['target_spend'].containing_oneof = _BIDDINGSTRATEGY.oneofs_by_name['scheme']
DESCRIPTOR.message_types_by_name['BiddingStrategy'] = _BIDDINGSTRATEGY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BiddingStrategy = _reflection.GeneratedProtocolMessageType('BiddingStrategy', (_message.Message,), dict(
  DESCRIPTOR = _BIDDINGSTRATEGY,
  __module__ = 'google.ads.googleads_v2.proto.resources.bidding_strategy_pb2'
  ,
  __doc__ = """A bidding strategy.
  
  
  Attributes:
      resource_name:
          The resource name of the bidding strategy. Bidding strategy
          resource names have the form:  ``customers/{customer_id}/biddi
          ngStrategies/{bidding_strategy_id}``
      id:
          The ID of the bidding strategy.
      name:
          The name of the bidding strategy. All bidding strategies
          within an account must be named distinctly.  The length of
          this string should be between 1 and 255, inclusive, in UTF-8
          bytes, (trimmed).
      status:
          The status of the bidding strategy.  This field is read-only.
      type:
          The type of the bidding strategy. Create a bidding strategy by
          setting the bidding scheme.  This field is read-only.
      campaign_count:
          The number of campaigns attached to this bidding strategy.
          This field is read-only.
      non_removed_campaign_count:
          The number of non-removed campaigns attached to this bidding
          strategy.  This field is read-only.
      scheme:
          The bidding scheme.  Only one can be set.
      enhanced_cpc:
          A bidding strategy that raises bids for clicks that seem more
          likely to lead to a conversion and lowers them for clicks
          where they seem less likely.
      page_one_promoted:
          A bidding strategy that sets max CPC bids to target
          impressions on page one or page one promoted slots on
          google.com. This field is deprecated. Creating a new bidding
          strategy with this field or attaching bidding strategies with
          this field to a campaign will fail. Mutates to strategies that
          already have this scheme populated are allowed.
      target_cpa:
          A bidding strategy that sets bids to help get as many
          conversions as possible at the target cost-per-acquisition
          (CPA) you set.
      target_impression_share:
          A bidding strategy that automatically optimizes towards a
          desired percentage of impressions.
      target_outrank_share:
          A bidding strategy that sets bids based on the target fraction
          of auctions where the advertiser should outrank a specific
          competitor. This field is deprecated. Creating a new bidding
          strategy with this field or attaching bidding strategies with
          this field to a campaign will fail. Mutates to strategies that
          already have this scheme populated are allowed.
      target_roas:
          A bidding strategy that helps you maximize revenue while
          averaging a specific target Return On Ad Spend (ROAS).
      target_spend:
          A bid strategy that sets your bids to help get as many clicks
          as possible within your budget.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.BiddingStrategy)
  ))
_sym_db.RegisterMessage(BiddingStrategy)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import user_interest_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_user__interest__pb2
from google.ads.google_ads.v1.proto.services import user_interest_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_user__interest__service__pb2


class UserInterestServiceStub(object):
  """Proto file describing the user interest service

  Service to fetch Google Ads User Interest.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetUserInterest = channel.unary_unary(
        '/google.ads.googleads.v1.services.UserInterestService/GetUserInterest',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_user__interest__service__pb2.GetUserInterestRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_user__interest__pb2.UserInterest.FromString,
        )


class UserInterestServiceServicer(object):
  """Proto file describing the user interest service

  Service to fetch Google Ads User Interest.
  """

  def GetUserInterest(self, request, context):
    """Returns the requested user interest in full detail
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_UserInterestServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetUserInterest': grpc.unary_unary_rpc_method_handler(
          servicer.GetUserInterest,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_user__interest__service__pb2.GetUserInterestRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_user__interest__pb2.UserInterest.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.UserInterestService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""A gRPC Interceptor that is responsible to augmenting request metadata.

This class is initialized in the GoogleAdsClient and passed into a grpc
intercept_channel whenever a new service is initialized. It intercepts requests
and updates the metadata in order to insert the developer token and
login-customer-id values.
"""

from grpc import UnaryUnaryClientInterceptor

from .interceptor_mixin import InterceptorMixin


class MetadataInterceptor(InterceptorMixin, UnaryUnaryClientInterceptor):
    """An interceptor that appends custom metadata to requests."""

    def __init__(self, developer_token, login_customer_id):
        self.developer_token_meta = ('developer-token', developer_token)
        self.login_customer_id_meta = (
            ('login-customer-id', login_customer_id) if login_customer_id
            else None)

    def _update_client_call_details_metadata(self, client_call_details,
                                             metadata):
        """Updates the client call details with additional metadata.

        Args:
            client_call_details: An instance of grpc.ClientCallDetails.
            metadata: Additional metadata defined by GoogleAdsClient.

        Returns:
            An new instance of grpc.ClientCallDetails with additional metadata
            from the GoogleAdsClient.
        """
        client_call_details = self.get_client_call_details_instance(
            client_call_details.method, client_call_details.timeout, metadata,
            client_call_details.credentials)

        return client_call_details

    def intercept_unary_unary(self, continuation, client_call_details, request):
        """Intercepts and appends custom metadata.

        Overrides abstract method defined in grpc.UnaryUnaryClientInterceptor.

        Returns:
            A grpc.Call/grpc.Future instance representing a service response.
        """
        if client_call_details.metadata is None:
            metadata = []
        else:
            metadata = list(client_call_details.metadata)

        metadata.append(self.developer_token_meta)

        if self.login_customer_id_meta:
            metadata.append(self.login_customer_id_meta)

        client_call_details = self._update_client_call_details_metadata(
            client_call_details,
            metadata)

        return continuation(client_call_details, request)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/keyword_plan_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import keyword_plan_common_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_keyword__plan__common__pb2
from google.ads.google_ads.v1.proto.resources import keyword_plan_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/keyword_plan_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\027KeywordPlanServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nAgoogle/ads/googleads_v1/proto/services/keyword_plan_service.proto\x12 google.ads.googleads.v1.services\x1a>google/ads/googleads_v1/proto/common/keyword_plan_common.proto\x1a:google/ads/googleads_v1/proto/resources/keyword_plan.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\".\n\x15GetKeywordPlanRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xac\x01\n\x19MutateKeywordPlansRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12J\n\noperations\x18\x02 \x03(\x0b\x32\x36.google.ads.googleads.v1.services.KeywordPlanOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"\xea\x01\n\x14KeywordPlanOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12@\n\x06\x63reate\x18\x01 \x01(\x0b\x32..google.ads.googleads.v1.resources.KeywordPlanH\x00\x12@\n\x06update\x18\x02 \x01(\x0b\x32..google.ads.googleads.v1.resources.KeywordPlanH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"\x9c\x01\n\x1aMutateKeywordPlansResponse\x12\x31\n\x15partial_failure_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12K\n\x07results\x18\x02 \x03(\x0b\x32:.google.ads.googleads.v1.services.MutateKeywordPlansResult\"1\n\x18MutateKeywordPlansResult\x12\x15\n\rresource_name\x18\x01 \x01(\t\"6\n\x1eGenerateForecastMetricsRequest\x12\x14\n\x0ckeyword_plan\x18\x01 \x01(\t\"\xaf\x02\n\x1fGenerateForecastMetricsResponse\x12Y\n\x12\x63\x61mpaign_forecasts\x18\x01 \x03(\x0b\x32=.google.ads.googleads.v1.services.KeywordPlanCampaignForecast\x12X\n\x12\x61\x64_group_forecasts\x18\x02 \x03(\x0b\x32<.google.ads.googleads.v1.services.KeywordPlanAdGroupForecast\x12W\n\x11keyword_forecasts\x18\x03 \x03(\x0b\x32<.google.ads.googleads.v1.services.KeywordPlanKeywordForecast\"\xa8\x01\n\x1bKeywordPlanCampaignForecast\x12;\n\x15keyword_plan_campaign\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12L\n\x11\x63\x61mpaign_forecast\x18\x02 \x01(\x0b\x32\x31.google.ads.googleads.v1.services.ForecastMetrics\"\xa7\x01\n\x1aKeywordPlanAdGroupForecast\x12;\n\x15keyword_plan_ad_group\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12L\n\x11\x61\x64_group_forecast\x18\x02 \x01(\x0b\x32\x31.google.ads.googleads.v1.services.ForecastMetrics\"\xae\x01\n\x1aKeywordPlanKeywordForecast\x12\x43\n\x1dkeyword_plan_ad_group_keyword\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12K\n\x10keyword_forecast\x18\x02 \x01(\x0b\x32\x31.google.ads.googleads.v1.services.ForecastMetrics\"\x81\x02\n\x0f\x46orecastMetrics\x12\x31\n\x0bimpressions\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12)\n\x03\x63tr\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0b\x61verage_cpc\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12,\n\x06\x63licks\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0b\x63ost_micros\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"8\n GenerateHistoricalMetricsRequest\x12\x14\n\x0ckeyword_plan\x18\x01 \x01(\t\"{\n!GenerateHistoricalMetricsResponse\x12V\n\x07metrics\x18\x01 \x03(\x0b\x32\x45.google.ads.googleads.v1.services.KeywordPlanKeywordHistoricalMetrics\"\xb0\x01\n#KeywordPlanKeywordHistoricalMetrics\x12\x32\n\x0csearch_query\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12U\n\x0fkeyword_metrics\x18\x02 \x01(\x0b\x32<.google.ads.googleads.v1.common.KeywordPlanHistoricalMetrics2\x86\x07\n\x12KeywordPlanService\x12\xb1\x01\n\x0eGetKeywordPlan\x12\x37.google.ads.googleads.v1.services.GetKeywordPlanRequest\x1a..google.ads.googleads.v1.resources.KeywordPlan\"6\x82\xd3\xe4\x93\x02\x30\x12./v1/{resource_name=customers/*/keywordPlans/*}\x12\xcd\x01\n\x12MutateKeywordPlans\x12;.google.ads.googleads.v1.services.MutateKeywordPlansRequest\x1a<.google.ads.googleads.v1.services.MutateKeywordPlansResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/v1/customers/{customer_id=*}/keywordPlans:mutate:\x01*\x12\xf0\x01\n\x17GenerateForecastMetrics\x12@.google.ads.googleads.v1.services.GenerateForecastMetricsRequest\x1a\x41.google.ads.googleads.v1.services.GenerateForecastMetricsResponse\"P\x82\xd3\xe4\x93\x02J\"E/v1/{keyword_plan=customers/*/keywordPlans/*}:generateForecastMetrics:\x01*\x12\xf8\x01\n\x19GenerateHistoricalMetrics\x12\x42.google.ads.googleads.v1.services.GenerateHistoricalMetricsRequest\x1a\x43.google.ads.googleads.v1.services.GenerateHistoricalMetricsResponse\"R\x82\xd3\xe4\x93\x02L\"G/v1/{keyword_plan=customers/*/keywordPlans/*}:generateHistoricalMetrics:\x01*B\xfe\x01\n$com.google.ads.googleads.v1.servicesB\x17KeywordPlanServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_keyword__plan__common__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_GETKEYWORDPLANREQUEST = _descriptor.Descriptor(
  name='GetKeywordPlanRequest',
  full_name='google.ads.googleads.v1.services.GetKeywordPlanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetKeywordPlanRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=394,
)


_MUTATEKEYWORDPLANSREQUEST = _descriptor.Descriptor(
  name='MutateKeywordPlansRequest',
  full_name='google.ads.googleads.v1.services.MutateKeywordPlansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.MutateKeywordPlansRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.MutateKeywordPlansRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v1.services.MutateKeywordPlansRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v1.services.MutateKeywordPlansRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=569,
)


_KEYWORDPLANOPERATION = _descriptor.Descriptor(
  name='KeywordPlanOperation',
  full_name='google.ads.googleads.v1.services.KeywordPlanOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v1.services.KeywordPlanOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v1.services.KeywordPlanOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v1.services.KeywordPlanOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v1.services.KeywordPlanOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.KeywordPlanOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=572,
  serialized_end=806,
)


_MUTATEKEYWORDPLANSRESPONSE = _descriptor.Descriptor(
  name='MutateKeywordPlansResponse',
  full_name='google.ads.googleads.v1.services.MutateKeywordPlansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v1.services.MutateKeywordPlansResponse.partial_failure_error', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.MutateKeywordPlansResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=965,
)


_MUTATEKEYWORDPLANSRESULT = _descriptor.Descriptor(
  name='MutateKeywordPlansResult',
  full_name='google.ads.googleads.v1.services.MutateKeywordPlansResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.MutateKeywordPlansResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=967,
  serialized_end=1016,
)


_GENERATEFORECASTMETRICSREQUEST = _descriptor.Descriptor(
  name='GenerateForecastMetricsRequest',
  full_name='google.ads.googleads.v1.services.GenerateForecastMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyword_plan', full_name='google.ads.googleads.v1.services.GenerateForecastMetricsRequest.keyword_plan', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1072,
)


_GENERATEFORECASTMETRICSRESPONSE = _descriptor.Descriptor(
  name='GenerateForecastMetricsResponse',
  full_name='google.ads.googleads.v1.services.GenerateForecastMetricsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='campaign_forecasts', full_name='google.ads.googleads.v1.services.GenerateForecastMetricsResponse.campaign_forecasts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_forecasts', full_name='google.ads.googleads.v1.services.GenerateForecastMetricsResponse.ad_group_forecasts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_forecasts', full_name='google.ads.googleads.v1.services.GenerateForecastMetricsResponse.keyword_forecasts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1075,
  serialized_end=1378,
)


_KEYWORDPLANCAMPAIGNFORECAST = _descriptor.Descriptor(
  name='KeywordPlanCampaignForecast',
  full_name='google.ads.googleads.v1.services.KeywordPlanCampaignForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyword_plan_campaign', full_name='google.ads.googleads.v1.services.KeywordPlanCampaignForecast.keyword_plan_campaign', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_forecast', full_name='google.ads.googleads.v1.services.KeywordPlanCampaignForecast.campaign_forecast', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1381,
  serialized_end=1549,
)


_KEYWORDPLANADGROUPFORECAST = _descriptor.Descriptor(
  name='KeywordPlanAdGroupForecast',
  full_name='google.ads.googleads.v1.services.KeywordPlanAdGroupForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyword_plan_ad_group', full_name='google.ads.googleads.v1.services.KeywordPlanAdGroupForecast.keyword_plan_ad_group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_forecast', full_name='google.ads.googleads.v1.services.KeywordPlanAdGroupForecast.ad_group_forecast', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1552,
  serialized_end=1719,
)


_KEYWORDPLANKEYWORDFORECAST = _descriptor.Descriptor(
  name='KeywordPlanKeywordForecast',
  full_name='google.ads.googleads.v1.services.KeywordPlanKeywordForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyword_plan_ad_group_keyword', full_name='google.ads.googleads.v1.services.KeywordPlanKeywordForecast.keyword_plan_ad_group_keyword', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_forecast', full_name='google.ads.googleads.v1.services.KeywordPlanKeywordForecast.keyword_forecast', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1722,
  serialized_end=1896,
)


_FORECASTMETRICS = _descriptor.Descriptor(
  name='ForecastMetrics',
  full_name='google.ads.googleads.v1.services.ForecastMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='impressions', full_name='google.ads.googleads.v1.services.ForecastMetrics.impressions', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ctr', full_name='google.ads.googleads.v1.services.ForecastMetrics.ctr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='average_cpc', full_name='google.ads.googleads.v1.services.ForecastMetrics.average_cpc', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clicks', full_name='google.ads.googleads.v1.services.ForecastMetrics.clicks', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_micros', full_name='google.ads.googleads.v1.services.ForecastMetrics.cost_micros', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1899,
  serialized_end=2156,
)


_GENERATEHISTORICALMETRICSREQUEST = _descriptor.Descriptor(
  name='GenerateHistoricalMetricsRequest',
  full_name='google.ads.googleads.v1.services.GenerateHistoricalMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyword_plan', full_name='google.ads.googleads.v1.services.GenerateHistoricalMetricsRequest.keyword_plan', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2158,
  serialized_end=2214,
)


_GENERATEHISTORICALMETRICSRESPONSE = _descriptor.Descriptor(
  name='GenerateHistoricalMetricsResponse',
  full_name='google.ads.googleads.v1.services.GenerateHistoricalMetricsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='google.ads.googleads.v1.services.GenerateHistoricalMetricsResponse.metrics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2216,
  serialized_end=2339,
)


_KEYWORDPLANKEYWORDHISTORICALMETRICS = _descriptor.Descriptor(
  name='KeywordPlanKeywordHistoricalMetrics',
  full_name='google.ads.googleads.v1.services.KeywordPlanKeywordHistoricalMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_query', full_name='google.ads.googleads.v1.services.KeywordPlanKeywordHistoricalMetrics.search_query', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_metrics', full_name='google.ads.googleads.v1.services.KeywordPlanKeywordHistoricalMetrics.keyword_metrics', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2342,
  serialized_end=2518,
)

_MUTATEKEYWORDPLANSREQUEST.fields_by_name['operations'].message_type = _KEYWORDPLANOPERATION
_KEYWORDPLANOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_KEYWORDPLANOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2._KEYWORDPLAN
_KEYWORDPLANOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2._KEYWORDPLAN
_KEYWORDPLANOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANOPERATION.fields_by_name['create'])
_KEYWORDPLANOPERATION.fields_by_name['create'].containing_oneof = _KEYWORDPLANOPERATION.oneofs_by_name['operation']
_KEYWORDPLANOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANOPERATION.fields_by_name['update'])
_KEYWORDPLANOPERATION.fields_by_name['update'].containing_oneof = _KEYWORDPLANOPERATION.oneofs_by_name['operation']
_KEYWORDPLANOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANOPERATION.fields_by_name['remove'])
_KEYWORDPLANOPERATION.fields_by_name['remove'].containing_oneof = _KEYWORDPLANOPERATION.oneofs_by_name['operation']
_MUTATEKEYWORDPLANSRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_MUTATEKEYWORDPLANSRESPONSE.fields_by_name['results'].message_type = _MUTATEKEYWORDPLANSRESULT
_GENERATEFORECASTMETRICSRESPONSE.fields_by_name['campaign_forecasts'].message_type = _KEYWORDPLANCAMPAIGNFORECAST
_GENERATEFORECASTMETRICSRESPONSE.fields_by_name['ad_group_forecasts'].message_type = _KEYWORDPLANADGROUPFORECAST
_GENERATEFORECASTMETRICSRESPONSE.fields_by_name['keyword_forecasts'].message_type = _KEYWORDPLANKEYWORDFORECAST
_KEYWORDPLANCAMPAIGNFORECAST.fields_by_name['keyword_plan_campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANCAMPAIGNFORECAST.fields_by_name['campaign_forecast'].message_type = _FORECASTMETRICS
_KEYWORDPLANADGROUPFORECAST.fields_by_name['keyword_plan_ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANADGROUPFORECAST.fields_by_name['ad_group_forecast'].message_type = _FORECASTMETRICS
_KEYWORDPLANKEYWORDFORECAST.fields_by_name['keyword_plan_ad_group_keyword'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANKEYWORDFORECAST.fields_by_name['keyword_forecast'].message_type = _FORECASTMETRICS
_FORECASTMETRICS.fields_by_name['impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_FORECASTMETRICS.fields_by_name['ctr'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_FORECASTMETRICS.fields_by_name['average_cpc'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FORECASTMETRICS.fields_by_name['clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_FORECASTMETRICS.fields_by_name['cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GENERATEHISTORICALMETRICSRESPONSE.fields_by_name['metrics'].message_type = _KEYWORDPLANKEYWORDHISTORICALMETRICS
_KEYWORDPLANKEYWORDHISTORICALMETRICS.fields_by_name['search_query'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANKEYWORDHISTORICALMETRICS.fields_by_name['keyword_metrics'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_keyword__plan__common__pb2._KEYWORDPLANHISTORICALMETRICS
DESCRIPTOR.message_types_by_name['GetKeywordPlanRequest'] = _GETKEYWORDPLANREQUEST
DESCRIPTOR.message_types_by_name['MutateKeywordPlansRequest'] = _MUTATEKEYWORDPLANSREQUEST
DESCRIPTOR.message_types_by_name['KeywordPlanOperation'] = _KEYWORDPLANOPERATION
DESCRIPTOR.message_types_by_name['MutateKeywordPlansResponse'] = _MUTATEKEYWORDPLANSRESPONSE
DESCRIPTOR.message_types_by_name['MutateKeywordPlansResult'] = _MUTATEKEYWORDPLANSRESULT
DESCRIPTOR.message_types_by_name['GenerateForecastMetricsRequest'] = _GENERATEFORECASTMETRICSREQUEST
DESCRIPTOR.message_types_by_name['GenerateForecastMetricsResponse'] = _GENERATEFORECASTMETRICSRESPONSE
DESCRIPTOR.message_types_by_name['KeywordPlanCampaignForecast'] = _KEYWORDPLANCAMPAIGNFORECAST
DESCRIPTOR.message_types_by_name['KeywordPlanAdGroupForecast'] = _KEYWORDPLANADGROUPFORECAST
DESCRIPTOR.message_types_by_name['KeywordPlanKeywordForecast'] = _KEYWORDPLANKEYWORDFORECAST
DESCRIPTOR.message_types_by_name['ForecastMetrics'] = _FORECASTMETRICS
DESCRIPTOR.message_types_by_name['GenerateHistoricalMetricsRequest'] = _GENERATEHISTORICALMETRICSREQUEST
DESCRIPTOR.message_types_by_name['GenerateHistoricalMetricsResponse'] = _GENERATEHISTORICALMETRICSRESPONSE
DESCRIPTOR.message_types_by_name['KeywordPlanKeywordHistoricalMetrics'] = _KEYWORDPLANKEYWORDHISTORICALMETRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetKeywordPlanRequest = _reflection.GeneratedProtocolMessageType('GetKeywordPlanRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETKEYWORDPLANREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanService.GetKeywordPlan][google.ads.googleads.v1.services.KeywordPlanService.GetKeywordPlan].
  
  
  Attributes:
      resource_name:
          The resource name of the plan to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetKeywordPlanRequest)
  ))
_sym_db.RegisterMessage(GetKeywordPlanRequest)

MutateKeywordPlansRequest = _reflection.GeneratedProtocolMessageType('MutateKeywordPlansRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanService.MutateKeywordPlans][google.ads.googleads.v1.services.KeywordPlanService.MutateKeywordPlans].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose keyword plans are being modified.
      operations:
          The list of operations to perform on individual keyword plans.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. Default is false.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateKeywordPlansRequest)
  ))
_sym_db.RegisterMessage(MutateKeywordPlansRequest)

KeywordPlanOperation = _reflection.GeneratedProtocolMessageType('KeywordPlanOperation', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a keyword plan.
  
  
  Attributes:
      update_mask:
          The FieldMask that determines which resource fields are
          modified in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          keyword plan.
      update:
          Update operation: The keyword plan is expected to have a valid
          resource name.
      remove:
          Remove operation: A resource name for the removed keyword plan
          is expected in this format:
          ``customers/{customer_id}/keywordPlans/{keyword_plan_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.KeywordPlanOperation)
  ))
_sym_db.RegisterMessage(KeywordPlanOperation)

MutateKeywordPlansResponse = _reflection.GeneratedProtocolMessageType('MutateKeywordPlansResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """Response message for a keyword plan mutate.
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors), we return an RPC
          level error.
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateKeywordPlansResponse)
  ))
_sym_db.RegisterMessage(MutateKeywordPlansResponse)

MutateKeywordPlansResult = _reflection.GeneratedProtocolMessageType('MutateKeywordPlansResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANSRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """The result for the keyword plan mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateKeywordPlansResult)
  ))
_sym_db.RegisterMessage(MutateKeywordPlansResult)

GenerateForecastMetricsRequest = _reflection.GeneratedProtocolMessageType('GenerateForecastMetricsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEFORECASTMETRICSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanService.GenerateForecastMetrics][google.ads.googleads.v1.services.KeywordPlanService.GenerateForecastMetrics].
  
  
  Attributes:
      keyword_plan:
          The resource name of the keyword plan to be forecasted.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GenerateForecastMetricsRequest)
  ))
_sym_db.RegisterMessage(GenerateForecastMetricsRequest)

GenerateForecastMetricsResponse = _reflection.GeneratedProtocolMessageType('GenerateForecastMetricsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEFORECASTMETRICSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """Response message for
  [KeywordPlanService.GenerateForecastMetrics][google.ads.googleads.v1.services.KeywordPlanService.GenerateForecastMetrics].
  
  
  Attributes:
      campaign_forecasts:
          List of campaign forecasts. One maximum.
      ad_group_forecasts:
          List of ad group forecasts.
      keyword_forecasts:
          List of keyword forecasts.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GenerateForecastMetricsResponse)
  ))
_sym_db.RegisterMessage(GenerateForecastMetricsResponse)

KeywordPlanCampaignForecast = _reflection.GeneratedProtocolMessageType('KeywordPlanCampaignForecast', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANCAMPAIGNFORECAST,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """A campaign forecast.
  
  
  Attributes:
      keyword_plan_campaign:
          The resource name of the Keyword Plan campaign related to the
          forecast.  ``customers/{customer_id}/keywordPlanCampaigns/{key
          word+plan_campaign_id}``
      campaign_forecast:
          The forecast for the Keyword Plan campaign.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.KeywordPlanCampaignForecast)
  ))
_sym_db.RegisterMessage(KeywordPlanCampaignForecast)

KeywordPlanAdGroupForecast = _reflection.GeneratedProtocolMessageType('KeywordPlanAdGroupForecast', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANADGROUPFORECAST,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """An ad group forecast.
  
  
  Attributes:
      keyword_plan_ad_group:
          The resource name of the Keyword Plan ad group related to the
          forecast.  ``customers/{customer_id}/keywordPlanAdGroups/{keyw
          ord_plan_ad_group_id}``
      ad_group_forecast:
          The forecast for the Keyword Plan ad group.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.KeywordPlanAdGroupForecast)
  ))
_sym_db.RegisterMessage(KeywordPlanAdGroupForecast)

KeywordPlanKeywordForecast = _reflection.GeneratedProtocolMessageType('KeywordPlanKeywordForecast', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANKEYWORDFORECAST,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """A keyword forecast.
  
  
  Attributes:
      keyword_plan_ad_group_keyword:
          The resource name of the Keyword Plan keyword related to the
          forecast.  ``customers/{customer_id}/keywordPlanAdGroupKeyword
          s/{keyword_plan_ad_group_keyword_id}``
      keyword_forecast:
          The forecast for the Keyword Plan keyword.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.KeywordPlanKeywordForecast)
  ))
_sym_db.RegisterMessage(KeywordPlanKeywordForecast)

ForecastMetrics = _reflection.GeneratedProtocolMessageType('ForecastMetrics', (_message.Message,), dict(
  DESCRIPTOR = _FORECASTMETRICS,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """Forecast metrics.
  
  
  Attributes:
      impressions:
          Impressions
      ctr:
          Ctr
      average_cpc:
          AVG cpc
      clicks:
          Clicks
      cost_micros:
          Cost
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ForecastMetrics)
  ))
_sym_db.RegisterMessage(ForecastMetrics)

GenerateHistoricalMetricsRequest = _reflection.GeneratedProtocolMessageType('GenerateHistoricalMetricsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEHISTORICALMETRICSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanService.GenerateHistoricalMetrics][google.ads.googleads.v1.services.KeywordPlanService.GenerateHistoricalMetrics].
  
  
  Attributes:
      keyword_plan:
          The resource name of the keyword plan of which historical
          metrics are requested.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GenerateHistoricalMetricsRequest)
  ))
_sym_db.RegisterMessage(GenerateHistoricalMetricsRequest)

GenerateHistoricalMetricsResponse = _reflection.GeneratedProtocolMessageType('GenerateHistoricalMetricsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEHISTORICALMETRICSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """Response message for
  [KeywordPlanService.GenerateHistoricalMetrics][google.ads.googleads.v1.services.KeywordPlanService.GenerateHistoricalMetrics].
  
  
  Attributes:
      metrics:
          List of keyword historical metrics.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GenerateHistoricalMetricsResponse)
  ))
_sym_db.RegisterMessage(GenerateHistoricalMetricsResponse)

KeywordPlanKeywordHistoricalMetrics = _reflection.GeneratedProtocolMessageType('KeywordPlanKeywordHistoricalMetrics', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANKEYWORDHISTORICALMETRICS,
  __module__ = 'google.ads.googleads_v1.proto.services.keyword_plan_service_pb2'
  ,
  __doc__ = """A keyword historical metrics.
  
  
  Attributes:
      search_query:
          The text of the query associated with one or more
          ad\_group\_keywords in the plan.  Note that we de-dupe your
          keywords list, eliminating close variants before returning the
          plan's keywords as text. For example, if your plan originally
          contained the keywords 'car' and 'cars', the returned search
          query will only contain 'car'.
      keyword_metrics:
          The historical metrics for the query associated with one or
          more ad\_group\_keywords in the plan.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.KeywordPlanKeywordHistoricalMetrics)
  ))
_sym_db.RegisterMessage(KeywordPlanKeywordHistoricalMetrics)


DESCRIPTOR._options = None

_KEYWORDPLANSERVICE = _descriptor.ServiceDescriptor(
  name='KeywordPlanService',
  full_name='google.ads.googleads.v1.services.KeywordPlanService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2521,
  serialized_end=3423,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetKeywordPlan',
    full_name='google.ads.googleads.v1.services.KeywordPlanService.GetKeywordPlan',
    index=0,
    containing_service=None,
    input_type=_GETKEYWORDPLANREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2._KEYWORDPLAN,
    serialized_options=_b('\202\323\344\223\0020\022./v1/{resource_name=customers/*/keywordPlans/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateKeywordPlans',
    full_name='google.ads.googleads.v1.services.KeywordPlanService.MutateKeywordPlans',
    index=1,
    containing_service=None,
    input_type=_MUTATEKEYWORDPLANSREQUEST,
    output_type=_MUTATEKEYWORDPLANSRESPONSE,
    serialized_options=_b('\202\323\344\223\0026\"1/v1/customers/{customer_id=*}/keywordPlans:mutate:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GenerateForecastMetrics',
    full_name='google.ads.googleads.v1.services.KeywordPlanService.GenerateForecastMetrics',
    index=2,
    containing_service=None,
    input_type=_GENERATEFORECASTMETRICSREQUEST,
    output_type=_GENERATEFORECASTMETRICSRESPONSE,
    serialized_options=_b('\202\323\344\223\002J\"E/v1/{keyword_plan=customers/*/keywordPlans/*}:generateForecastMetrics:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GenerateHistoricalMetrics',
    full_name='google.ads.googleads.v1.services.KeywordPlanService.GenerateHistoricalMetrics',
    index=3,
    containing_service=None,
    input_type=_GENERATEHISTORICALMETRICSREQUEST,
    output_type=_GENERATEHISTORICALMETRICSRESPONSE,
    serialized_options=_b('\202\323\344\223\002L\"G/v1/{keyword_plan=customers/*/keywordPlans/*}:generateHistoricalMetrics:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYWORDPLANSERVICE)

DESCRIPTOR.services_by_name['KeywordPlanService'] = _KEYWORDPLANSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import ad_group_ad_label_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__group__ad__label__pb2
from google.ads.google_ads.v1.proto.services import ad_group_ad_label_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2


class AdGroupAdLabelServiceStub(object):
  """Proto file describing the Ad Group Ad Label service.

  Service to manage labels on ad group ads.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetAdGroupAdLabel = channel.unary_unary(
        '/google.ads.googleads.v1.services.AdGroupAdLabelService/GetAdGroupAdLabel',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2.GetAdGroupAdLabelRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__group__ad__label__pb2.AdGroupAdLabel.FromString,
        )
    self.MutateAdGroupAdLabels = channel.unary_unary(
        '/google.ads.googleads.v1.services.AdGroupAdLabelService/MutateAdGroupAdLabels',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2.MutateAdGroupAdLabelsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2.MutateAdGroupAdLabelsResponse.FromString,
        )


class AdGroupAdLabelServiceServicer(object):
  """Proto file describing the Ad Group Ad Label service.

  Service to manage labels on ad group ads.
  """

  def GetAdGroupAdLabel(self, request, context):
    """Returns the requested ad group ad label in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateAdGroupAdLabels(self, request, context):
    """Creates and removes ad group ad labels.
    Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdGroupAdLabelServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetAdGroupAdLabel': grpc.unary_unary_rpc_method_handler(
          servicer.GetAdGroupAdLabel,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2.GetAdGroupAdLabelRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__group__ad__label__pb2.AdGroupAdLabel.SerializeToString,
      ),
      'MutateAdGroupAdLabels': grpc.unary_unary_rpc_method_handler(
          servicer.MutateAdGroupAdLabels,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2.MutateAdGroupAdLabelsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__group__ad__label__service__pb2.MutateAdGroupAdLabelsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.AdGroupAdLabelService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/conversion_lag_bucket.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/conversion_lag_bucket.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\030ConversionLagBucketProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\n?google/ads/googleads_v1/proto/enums/conversion_lag_bucket.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xbb\x04\n\x17\x43onversionLagBucketEnum\"\x9f\x04\n\x13\x43onversionLagBucket\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x15\n\x11LESS_THAN_ONE_DAY\x10\x02\x12\x13\n\x0fONE_TO_TWO_DAYS\x10\x03\x12\x15\n\x11TWO_TO_THREE_DAYS\x10\x04\x12\x16\n\x12THREE_TO_FOUR_DAYS\x10\x05\x12\x15\n\x11\x46OUR_TO_FIVE_DAYS\x10\x06\x12\x14\n\x10\x46IVE_TO_SIX_DAYS\x10\x07\x12\x15\n\x11SIX_TO_SEVEN_DAYS\x10\x08\x12\x17\n\x13SEVEN_TO_EIGHT_DAYS\x10\t\x12\x16\n\x12\x45IGHT_TO_NINE_DAYS\x10\n\x12\x14\n\x10NINE_TO_TEN_DAYS\x10\x0b\x12\x16\n\x12TEN_TO_ELEVEN_DAYS\x10\x0c\x12\x19\n\x15\x45LEVEN_TO_TWELVE_DAYS\x10\r\x12\x1b\n\x17TWELVE_TO_THIRTEEN_DAYS\x10\x0e\x12\x1d\n\x19THIRTEEN_TO_FOURTEEN_DAYS\x10\x0f\x12\x1f\n\x1b\x46OURTEEN_TO_TWENTY_ONE_DAYS\x10\x10\x12\x1d\n\x19TWENTY_ONE_TO_THIRTY_DAYS\x10\x11\x12\x1d\n\x19THIRTY_TO_FORTY_FIVE_DAYS\x10\x12\x12\x1c\n\x18\x46ORTY_FIVE_TO_SIXTY_DAYS\x10\x13\x12\x18\n\x14SIXTY_TO_NINETY_DAYS\x10\x14\x42\xed\x01\n!com.google.ads.googleads.v1.enumsB\x18\x43onversionLagBucketProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CONVERSIONLAGBUCKETENUM_CONVERSIONLAGBUCKET = _descriptor.EnumDescriptor(
  name='ConversionLagBucket',
  full_name='google.ads.googleads.v1.enums.ConversionLagBucketEnum.ConversionLagBucket',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_ONE_DAY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONE_TO_TWO_DAYS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TWO_TO_THREE_DAYS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THREE_TO_FOUR_DAYS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FOUR_TO_FIVE_DAYS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIVE_TO_SIX_DAYS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIX_TO_SEVEN_DAYS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEVEN_TO_EIGHT_DAYS', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EIGHT_TO_NINE_DAYS', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NINE_TO_TEN_DAYS', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEN_TO_ELEVEN_DAYS', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ELEVEN_TO_TWELVE_DAYS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TWELVE_TO_THIRTEEN_DAYS', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIRTEEN_TO_FOURTEEN_DAYS', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FOURTEEN_TO_TWENTY_ONE_DAYS', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TWENTY_ONE_TO_THIRTY_DAYS', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIRTY_TO_FORTY_FIVE_DAYS', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORTY_FIVE_TO_SIXTY_DAYS', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIXTY_TO_NINETY_DAYS', index=20, number=20,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=157,
  serialized_end=700,
)
_sym_db.RegisterEnumDescriptor(_CONVERSIONLAGBUCKETENUM_CONVERSIONLAGBUCKET)


_CONVERSIONLAGBUCKETENUM = _descriptor.Descriptor(
  name='ConversionLagBucketEnum',
  full_name='google.ads.googleads.v1.enums.ConversionLagBucketEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONVERSIONLAGBUCKETENUM_CONVERSIONLAGBUCKET,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=700,
)

_CONVERSIONLAGBUCKETENUM_CONVERSIONLAGBUCKET.containing_type = _CONVERSIONLAGBUCKETENUM
DESCRIPTOR.message_types_by_name['ConversionLagBucketEnum'] = _CONVERSIONLAGBUCKETENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConversionLagBucketEnum = _reflection.GeneratedProtocolMessageType('ConversionLagBucketEnum', (_message.Message,), dict(
  DESCRIPTOR = _CONVERSIONLAGBUCKETENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.conversion_lag_bucket_pb2'
  ,
  __doc__ = """Container for enum representing the number of days between impression
  and conversion.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.ConversionLagBucketEnum)
  ))
_sym_db.RegisterMessage(ConversionLagBucketEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import asset_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_asset__pb2
from google.ads.google_ads.v1.proto.services import asset_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_asset__service__pb2


class AssetServiceStub(object):
  """Proto file describing the Asset service.

  Service to manage assets. Asset types can be created with AssetService are
  YoutubeVideoAsset, MediaBundleAsset and ImageAsset. TextAsset should be
  created with Ad inline.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetAsset = channel.unary_unary(
        '/google.ads.googleads.v1.services.AssetService/GetAsset',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_asset__service__pb2.GetAssetRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_asset__pb2.Asset.FromString,
        )
    self.MutateAssets = channel.unary_unary(
        '/google.ads.googleads.v1.services.AssetService/MutateAssets',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_asset__service__pb2.MutateAssetsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_asset__service__pb2.MutateAssetsResponse.FromString,
        )


class AssetServiceServicer(object):
  """Proto file describing the Asset service.

  Service to manage assets. Asset types can be created with AssetService are
  YoutubeVideoAsset, MediaBundleAsset and ImageAsset. TextAsset should be
  created with Ad inline.
  """

  def GetAsset(self, request, context):
    """Returns the requested asset in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateAssets(self, request, context):
    """Creates assets. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AssetServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetAsset': grpc.unary_unary_rpc_method_handler(
          servicer.GetAsset,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_asset__service__pb2.GetAssetRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_asset__pb2.Asset.SerializeToString,
      ),
      'MutateAssets': grpc.unary_unary_rpc_method_handler(
          servicer.MutateAssets,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_asset__service__pb2.MutateAssetsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_asset__service__pb2.MutateAssetsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.AssetService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
